@@ -36,6 +36,7 @@
 #include "grl-tracker-media-api.h"
 #include "grl-tracker-media-notif.h"
 #include "grl-tracker-metadata.h"
+#include "grl-tracker-request-queue.h"
 #include "grl-tracker-utils.h"
 
 /* --------- Logging  -------- */
@@ -76,6 +77,7 @@ gboolean grl_tracker_plugin_init (GrlPluginRegistry *registry,
 TrackerSparqlConnection *grl_tracker_connection = NULL;
 const GrlPluginInfo *grl_tracker_plugin;
 gboolean grl_tracker_upnp_present = FALSE;
+GrlTrackerQueue *grl_tracker_queue = NULL;
 
 /* tracker plugin config */
 gboolean grl_tracker_per_device_source = FALSE;
@@ -88,6 +90,8 @@ init_sources (void)
 {
   grl_tracker_setup_key_mappings ();
 
+  grl_tracker_queue = grl_tracker_queue_new ();
+
   if (grl_tracker_connection != NULL) {
     grl_tracker_media_dbus_start_watch ();
 
@@ -183,11 +187,18 @@ tracker_get_connection_cb (GObject             *object,
                            GAsyncResult        *res,
                            const GrlPluginInfo *plugin)
 {
+  GError *error = NULL;
   /* GrlTrackerMedia *source; */
 
   GRL_DEBUG ("%s", __FUNCTION__);
 
-  grl_tracker_connection = tracker_sparql_connection_get_finish (res, NULL);
+  grl_tracker_connection = tracker_sparql_connection_get_finish (res, &error);
+
+  if (error) {
+    GRL_WARNING ("Could not get connection to Tracker: %s", error->message);
+    g_error_free (error);
+    return;
+  }
 
   GRL_DEBUG ("\trequest : '%s'", TRACKER_UPNP_CLASS_REQUEST);
 
